/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/lookandfeel/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ItemModelRowE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemModelRow::qt_create_metaobjectdata<qt_meta_tag_ZN12ItemModelRowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemModelRow",
        "modelChanged",
        "",
        "roleChanged",
        "valueChanged",
        "indexChanged",
        "model",
        "QAbstractItemModel*",
        "role",
        "value",
        "QVariant",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'model'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'role'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'index'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemModelRow, qt_meta_tag_ZN12ItemModelRowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemModelRow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemModelRowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemModelRowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ItemModelRowE_t>.metaTypes,
    nullptr
} };

void ItemModelRow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemModelRow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->roleChanged(); break;
        case 2: _t->valueChanged(); break;
        case 3: _t->indexChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemModelRow::*)()>(_a, &ItemModelRow::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemModelRow::*)()>(_a, &ItemModelRow::roleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemModelRow::*)()>(_a, &ItemModelRow::valueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemModelRow::*)()>(_a, &ItemModelRow::indexChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->role(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->index(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1: _t->setRole(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setValue(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ItemModelRow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemModelRow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemModelRowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemModelRow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ItemModelRow::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ItemModelRow::roleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ItemModelRow::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ItemModelRow::indexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN22LookAndFeelInformationE_t {};
} // unnamed namespace

template <> constexpr inline auto LookAndFeelInformation::qt_create_metaobjectdata<qt_meta_tag_ZN22LookAndFeelInformationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LookAndFeelInformation",
        "packageIdChanged",
        "",
        "modelChanged",
        "nameChanged",
        "previewChanged",
        "variantChanged",
        "packageId",
        "model",
        "QStandardItemModel*",
        "name",
        "preview",
        "QUrl",
        "variant",
        "KLookAndFeel::Variant"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'packageIdChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'variantChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'packageId'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'model'
        QtMocHelpers::PropertyData<QStandardItemModel*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'preview'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'variant'
        QtMocHelpers::PropertyData<KLookAndFeel::Variant>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LookAndFeelInformation, qt_meta_tag_ZN22LookAndFeelInformationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN22LookAndFeelInformationE[] = {
    QMetaObject::SuperData::link<KLookAndFeel::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject LookAndFeelInformation::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LookAndFeelInformationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LookAndFeelInformationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN22LookAndFeelInformationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22LookAndFeelInformationE_t>.metaTypes,
    nullptr
} };

void LookAndFeelInformation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LookAndFeelInformation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->packageIdChanged(); break;
        case 1: _t->modelChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->previewChanged(); break;
        case 4: _t->variantChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelInformation::*)()>(_a, &LookAndFeelInformation::packageIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelInformation::*)()>(_a, &LookAndFeelInformation::modelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelInformation::*)()>(_a, &LookAndFeelInformation::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelInformation::*)()>(_a, &LookAndFeelInformation::previewChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelInformation::*)()>(_a, &LookAndFeelInformation::variantChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QStandardItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->packageId(); break;
        case 1: *reinterpret_cast<QStandardItemModel**>(_v) = _t->model(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QUrl*>(_v) = _t->preview(); break;
        case 4: *reinterpret_cast<KLookAndFeel::Variant*>(_v) = _t->variant(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPackageId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setModel(*reinterpret_cast<QStandardItemModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LookAndFeelInformation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LookAndFeelInformation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LookAndFeelInformationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LookAndFeelInformation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LookAndFeelInformation::packageIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LookAndFeelInformation::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LookAndFeelInformation::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LookAndFeelInformation::previewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LookAndFeelInformation::variantChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN14KCMLookandFeelE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMLookandFeel::qt_create_metaobjectdata<qt_meta_tag_ZN14KCMLookandFeelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMLookandFeel",
        "showConfirmation",
        "",
        "themeContentsChanged",
        "selectedContentsChanged",
        "plasmaLockedChanged",
        "defaults",
        "apply",
        "saveCurrentTheme",
        "name",
        "QUrl",
        "preview",
        "removeRow",
        "pluginId",
        "removeDependencies",
        "knsEntryChanged",
        "KNSCore::Entry",
        "entry",
        "reloadConfig",
        "settings",
        "LookAndFeelSettings*",
        "model",
        "QStandardItemModel*",
        "themeContents",
        "KLookAndFeelManager::Contents",
        "selectedContents",
        "plasmaLocked",
        "Roles",
        "PluginNameRole",
        "ScreenshotRole",
        "FullScreenPreviewRole",
        "DescriptionRole",
        "ContentsRole",
        "PackagePathRole",
        "UninstallableRole",
        "VariantRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showConfirmation'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeContentsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedContentsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plasmaLockedChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'apply'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveCurrentTheme'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'removeRow'
        QtMocHelpers::MethodData<bool(const QString &, bool)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Method 'removeRow'
        QtMocHelpers::MethodData<bool(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'knsEntryChanged'
        QtMocHelpers::MethodData<void(const KNSCore::Entry &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'reloadConfig'
        QtMocHelpers::MethodData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'settings'
        QtMocHelpers::PropertyData<LookAndFeelSettings*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'model'
        QtMocHelpers::PropertyData<QStandardItemModel*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'themeContents'
        QtMocHelpers::PropertyData<KLookAndFeelManager::Contents>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'selectedContents'
        QtMocHelpers::PropertyData<KLookAndFeelManager::Contents>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'plasmaLocked'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(27, 27, QMC::EnumFlags{}).add({
            {   28, Roles::PluginNameRole },
            {   29, Roles::ScreenshotRole },
            {   30, Roles::FullScreenPreviewRole },
            {   31, Roles::DescriptionRole },
            {   32, Roles::ContentsRole },
            {   33, Roles::PackagePathRole },
            {   34, Roles::UninstallableRole },
            {   35, Roles::VariantRole },
        }),
    };
    return QtMocHelpers::metaObjectData<KCMLookandFeel, qt_meta_tag_ZN14KCMLookandFeelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN14KCMLookandFeelE[] = {
    QMetaObject::SuperData::link<KLookAndFeelManager::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KCMLookandFeel::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCMLookandFeelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCMLookandFeelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN14KCMLookandFeelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KCMLookandFeelE_t>.metaTypes,
    nullptr
} };

void KCMLookandFeel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMLookandFeel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showConfirmation(); break;
        case 1: _t->themeContentsChanged(); break;
        case 2: _t->selectedContentsChanged(); break;
        case 3: _t->plasmaLockedChanged(); break;
        case 4: _t->defaults(); break;
        case 5: _t->apply(); break;
        case 6: _t->saveCurrentTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 7: { bool _r = _t->removeRow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->removeRow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->knsEntryChanged((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1]))); break;
        case 10: _t->reloadConfig(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMLookandFeel::*)()>(_a, &KCMLookandFeel::showConfirmation, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMLookandFeel::*)()>(_a, &KCMLookandFeel::themeContentsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMLookandFeel::*)()>(_a, &KCMLookandFeel::selectedContentsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMLookandFeel::*)()>(_a, &KCMLookandFeel::plasmaLockedChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QStandardItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LookAndFeelSettings**>(_v) = _t->settings(); break;
        case 1: *reinterpret_cast<QStandardItemModel**>(_v) = _t->model(); break;
        case 2: *reinterpret_cast<KLookAndFeelManager::Contents*>(_v) = _t->themeContents(); break;
        case 3: *reinterpret_cast<KLookAndFeelManager::Contents*>(_v) = _t->selectedContents(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isPlasmaLocked(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setSelectedContents(*reinterpret_cast<KLookAndFeelManager::Contents*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 3: _t->resetSelectedContents(); break;
        default: break;
        }
    }
}

const QMetaObject *KCMLookandFeel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMLookandFeel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCMLookandFeelE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMLookandFeel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KCMLookandFeel::showConfirmation()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMLookandFeel::themeContentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMLookandFeel::selectedContentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMLookandFeel::plasmaLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
